Index: /trunk/src/org/openstreetmap/josm/gui/dialogs/InspectPrimitiveDataText.java
===================================================================
--- /trunk/src/org/openstreetmap/josm/gui/dialogs/InspectPrimitiveDataText.java	(revision 13185)
+++ /trunk/src/org/openstreetmap/josm/gui/dialogs/InspectPrimitiveDataText.java	(revision 13186)
@@ -221,5 +221,5 @@
             Pair<Integer, Hemisphere> utmZone = TransverseMercator.locateUtmZone(n.getCoor());
             String utmLabel = tr("UTM Zone");
-            add(utmLabel, utmLabel.endsWith(":") ? " " : ": ", Integer.toString(utmZone.a), utmZone.b.toString().substring(0, 1));
+            add(utmLabel, utmLabel.endsWith(":") ? " " : ": ", Integer.toString(utmZone.a), utmZone.b.name().substring(0, 1));
         }
     }
Index: /trunk/src/org/openstreetmap/josm/gui/layer/geoimage/ImageDisplay.java
===================================================================
--- /trunk/src/org/openstreetmap/josm/gui/layer/geoimage/ImageDisplay.java	(revision 13185)
+++ /trunk/src/org/openstreetmap/josm/gui/layer/geoimage/ImageDisplay.java	(revision 13186)
@@ -779,17 +779,15 @@
 
         // overscan to prevent empty edges when zooming in to zoom scales > 2:1
-        if (w > imgRect.width && h > imgRect.height && !imgRect.isFullView1D()) {
-            if (wFact != hFact) {
-                if (wFact > hFact) {
-                    w = compRect.width;
-                    x = 0;
-                    h = wFact / imgRect.width;
-                    y = (compRect.height - h) / 2;
-                } else {
-                    h = compRect.height;
-                    y = 0;
-                    w = hFact / imgRect.height;
-                    x = (compRect.width - w) / 2;
-                }
+        if (w > imgRect.width && h > imgRect.height && !imgRect.isFullView1D() && wFact != hFact) {
+            if (wFact > hFact) {
+                w = compRect.width;
+                x = 0;
+                h = wFact / imgRect.width;
+                y = (compRect.height - h) / 2;
+            } else {
+                h = compRect.height;
+                y = 0;
+                w = hFact / imgRect.height;
+                x = (compRect.width - w) / 2;
             }
         }
Index: /trunk/src/org/openstreetmap/josm/tools/ImageProvider.java
===================================================================
--- /trunk/src/org/openstreetmap/josm/tools/ImageProvider.java	(revision 13185)
+++ /trunk/src/org/openstreetmap/josm/tools/ImageProvider.java	(revision 13186)
@@ -1973,16 +1973,16 @@
      * Converts an {@link Rectangle} area of {@link Image} to a {@link BufferedImage} instance.
      * @param image image to convert
      * @param crop_area rectangle to crop image with
      * @return a {@code BufferedImage} instance for the cropped area of {@code Image}.
      * @since 13127
      */
-    public static BufferedImage toBufferedImage(Image image, Rectangle crop_area) {
+    public static BufferedImage toBufferedImage(Image image, Rectangle cropArea) {
         BufferedImage buffImage = null;
         Rectangle r = new Rectangle(image.getWidth(null), image.getHeight(null));
-        if (r.intersection(crop_area).equals(crop_area)) {
-            buffImage = new BufferedImage(crop_area.width, crop_area.height, BufferedImage.TYPE_INT_ARGB);
+        if (r.intersection(cropArea).equals(cropArea)) {
+            buffImage = new BufferedImage(cropArea.width, cropArea.height, BufferedImage.TYPE_INT_ARGB);
             Graphics2D g2 = buffImage.createGraphics();
-            g2.drawImage(image, 0, 0, crop_area.width, crop_area.height,
-                crop_area.x, crop_area.y, crop_area.x + crop_area.width, crop_area.y + crop_area.height, null);
+            g2.drawImage(image, 0, 0, cropArea.width, cropArea.height,
+                cropArea.x, cropArea.y, cropArea.x + cropArea.width, cropArea.y + cropArea.height, null);
             g2.dispose();
         }
@@ -1973,16 +1973,16 @@
      * Converts an {@link Rectangle} area of {@link Image} to a {@link BufferedImage} instance.
      * @param image image to convert
-     * @param crop_area rectangle to crop image with
+     * @param cropArea rectangle to crop image with
      * @return a {@code BufferedImage} instance for the cropped area of {@code Image}.
      * @since 13127
